import { HttpClient, HttpResponse } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { IStatistics } from 'app/shared/model/statistics.model';
import { createRequestOption } from 'app/core/request/request-util';
import { Search } from 'app/core/request/request.model';
import { Observable } from 'rxjs';

type EntityResponseType = HttpResponse<IStatistics>;
type EntityArrayResponseType = HttpResponse<IStatistics[]>;

@Injectable({ providedIn: 'root' })
export class StatisticsService {
  public resourceUrl = this.applicationConfigService.getEndpointFor('api/statistics');
  public resourceSearchUrl = this.applicationConfigService.getEndpointFor('api/_search/statistics');

  constructor(protected http: HttpClient, private applicationConfigService: ApplicationConfigService) {}

  create(statistics: IStatistics): Observable<EntityResponseType> {
    return this.http.post<IStatistics>(this.resourceUrl, statistics, { observe: 'response' });
  }

  update(statistics: IStatistics): Observable<EntityResponseType> {
    return this.http.put<IStatistics>(this.resourceUrl, statistics, { observe: 'response' });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<IStatistics>(`${this.resourceUrl}/${encodeURIComponent(id)}`, { observe: 'response' });
  }

  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IStatistics[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${encodeURIComponent(id)}`, { observe: 'response' });
  }

  search(req: Search): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IStatistics[]>(this.resourceSearchUrl, { params: options, observe: 'response' });
  }

  getNumberOfWatchListEntriesForExerciseID(exerciseID: string): Observable<number> {
    return this.http.get<number>(SERVER_API_URL + 'api/statistics/numberOfWatchlistEntries/' + encodeURIComponent(exerciseID));
  }
}
